#ifndef _SYS_SENDFILE_H_
#define _SYS_SENDFILE_H_


#ifdef __cplusplus
extern "C" {
#endif

#error "This header not permitted by the LSB"





#ifdef __cplusplus
}
#endif
#endif
